pub enum Cmd {
}Variants
Contract(Cmd)
Tools for smart contract developers
Doctor(Cmd)
Diagnose and troubleshoot CLI and network issues
Events(Cmd)
Watch the network for contract events
Env(Cmd)
Prints the environment variables
Prints to stdout in a format that can be used as .env file. Environment variables have precedence over defaults.
Pass a name to get the value of a single environment variable.
If there are no environment variables in use, prints the defaults.
Keys(Cmd)
Create and manage identities including keys and addresses
Network(Cmd)
Configure connection to networks
Container(Cmd)
Start local networks in containers
Config(Cmd)
Manage CLI configuration
Snapshot(Cmd)
Download a snapshot of a ledger from an archive.
Tx(Cmd)
Sign, Simulate, and Send transactions
Xdr(Root)
Decode and encode XDR
Strkey(Root)
Decode and encode strkey
Completion(Cmd)
Print shell completion code for the specified shell.
Cache(Cmd)
Cache for transactions and contract specs
Version(Cmd)
Print version information
Plugin(Cmd)
The subcommand for CLI plugins
Ledger(Cmd)
Fetch ledger information
Message(Cmd)
Sign and verify arbitrary messages using SEP-53
FeeStats(Cmd)
⚠️ Deprecated, use fees stats instead. Fetch network feestats
Fees(Cmd)
Fetch network feestats and configure CLI fee settings