soroban_cli::commands

Module plugin

Enums

Functions

  • Tries to run a plugin, if the plugin’s name is similar enough to any of the current subcommands return Ok. Otherwise only errors can be returned because this process will exit with the plugin.