pub struct Args {
pub network: Args,
pub source_account: UnresolvedMuxedAccount,
pub locator: Args,
pub sign_with: Args,
pub fee: Option<u32>,
pub inclusion_fee: Option<u32>,
}Fields
network: Argssource_account: UnresolvedMuxedAccountAccount that where transaction originates from. Alias source.
Can be an identity (–source alice), a public key (–source GDKW…),
a muxed account (–source MDA…), a secret key (–source SC36…),
or a seed phrase (–source “kite urban…”).
If --build-only was NOT provided, this key will also be used to
sign the final transaction. In that case, trying to sign with public key will fail.
locator: Argssign_with: Argsfee: Option<u32>⚠️ Deprecated, use --inclusion-fee. Fee amount for transaction, in stroops. 1 stroop = 0.0000001 xlm
inclusion_fee: Option<u32>Maximum fee amount for transaction inclusion, in stroops. 1 stroop = 0.0000001 xlm. Defaults to 100 if no arg, env, or config value is provided
Implementations
Sourceimpl Args
impl Args
pub fn source_account(&self) -> Result<MuxedAccount, Error>
pub fn key_pair(&self) -> Result<SigningKey, Error>
pub async fn sign( &self, tx: Transaction, quiet: bool, ) -> Result<TransactionEnvelope, Error>
pub async fn sign_fee_bump( &self, tx: FeeBumpTransaction, quiet: bool, ) -> Result<TransactionEnvelope, Error>
pub fn get_network(&self) -> Result<Network, Error>
Sourcepub fn get_inclusion_fee(&self) -> Result<u32, Error>
pub fn get_inclusion_fee(&self) -> Result<u32, Error>
Get the inclusion fee if available from args, otherwise fall back to fee, and finally return 100 if nothing is set.
Precedence is:
- inclusion_fee (via clap, arg then env var)
- fee (via clap, arg then env var)
- default of 100 stroops
pub async fn next_sequence_number( &self, account: impl Into<AccountId>, ) -> Result<SequenceNumber, Error>
pub fn hd_path(&self) -> Option<u32>