#[repr(i32)]pub enum TrustLineFlags {
AuthorizedFlag = 1,
AuthorizedToMaintainLiabilitiesFlag = 2,
TrustlineClawbackEnabledFlag = 4,
}Expand description
TrustLineFlags is an XDR Enum defined as:
enum TrustLineFlags
{
// issuer has authorized account to perform transactions with its credit
AUTHORIZED_FLAG = 1,
// issuer has authorized account to maintain and reduce liabilities for its
// credit
AUTHORIZED_TO_MAINTAIN_LIABILITIES_FLAG = 2,
// issuer has specified that it may clawback its credit, and that claimable
// balances created with its credit may also be clawed back
TRUSTLINE_CLAWBACK_ENABLED_FLAG = 4
};Variants
Implementations
Sourceimpl TrustLineFlags
impl TrustLineFlags
pub const VARIANTS: [TrustLineFlags; 3]
pub const VARIANTS_STR: [&'static str; 3]
pub const fn name(&self) -> &'static str
pub const fn variants() -> [TrustLineFlags; 3]