pub struct CreateAccountOp {
pub destination: AccountId,
pub starting_balance: i64,
}Expand description
CreateAccountOp is an XDR Struct defined as:
struct CreateAccountOp
{
AccountID destination; // account to create
int64 startingBalance; // amount they end up with
};Fields
destination: AccountIdstarting_balance: i64Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for CreateAccountOp
impl<'arbitrary> Arbitrary<'arbitrary> for CreateAccountOp
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<CreateAccountOp, Error>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<CreateAccountOp, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<CreateAccountOp, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<CreateAccountOp, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for CreateAccountOp
impl Clone for CreateAccountOp
Sourcefn clone(&self) -> CreateAccountOp
fn clone(&self) -> CreateAccountOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateAccountOp
impl Debug for CreateAccountOp
Sourceimpl Default for CreateAccountOp
impl Default for CreateAccountOp
Sourcefn default() -> CreateAccountOp
fn default() -> CreateAccountOp
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CreateAccountOp
impl<'de> Deserialize<'de> for CreateAccountOp
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CreateAccountOp, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CreateAccountOp, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CreateAccountOp
impl Hash for CreateAccountOp
Sourceimpl JsonSchema for CreateAccountOp
impl JsonSchema for CreateAccountOp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for CreateAccountOp
impl Ord for CreateAccountOp
Sourcefn cmp(&self, other: &CreateAccountOp) -> Ordering
fn cmp(&self, other: &CreateAccountOp) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CreateAccountOp
impl PartialEq for CreateAccountOp
Sourceimpl PartialOrd for CreateAccountOp
impl PartialOrd for CreateAccountOp
Sourceimpl ReadXdr for CreateAccountOp
impl ReadXdr for CreateAccountOp
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<CreateAccountOp, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<CreateAccountOp, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for CreateAccountOp
impl Serialize for CreateAccountOp
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for CreateAccountOp
impl WriteXdr for CreateAccountOp
impl Eq for CreateAccountOp
impl StructuralPartialEq for CreateAccountOp