pub struct Frame<T>(pub T)
where
T: ReadXdr;Expand description
Frame wraps an XDR object with the framing defined by the Record Marking Standard in RFC 5531 Section 11.
Each frame begins with a 4-byte big-endian header where:
- Bit 31 (high bit) is the last-fragment flag (
1= last fragment). - Bits 0-30 contain the byte length of the fragment data that follows.
A record is composed of one or more fragments. In Stellar’s usage each record contains exactly one XDR object encoded as a single fragment with the last-fragment bit set.
Tuple Fields
0: TTrait Implementations
Sourceimpl<'de, T> Deserialize<'de> for Frame<T>where
T: ReadXdr + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Frame<T>where
T: ReadXdr + Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Frame<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Frame<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> JsonSchema for Frame<T>where
T: JsonSchema + ReadXdr,
Available on crate feature schemars only.
impl<T> JsonSchema for Frame<T>where
T: JsonSchema + ReadXdr,
Available on crate feature
schemars only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<T> Ord for Frame<T>
impl<T> Ord for Frame<T>
Sourceimpl<T> PartialOrd for Frame<T>where
T: PartialOrd + ReadXdr,
impl<T> PartialOrd for Frame<T>where
T: PartialOrd + ReadXdr,
Sourceimpl<T> ReadXdr for Frame<T>where
T: ReadXdr,
impl<T> ReadXdr for Frame<T>where
T: ReadXdr,
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<Frame<T>, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<Frame<T>, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl<T> Serialize for Frame<T>
impl<T> Serialize for Frame<T>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<T> Eq for Frame<T>
impl<T> StructuralPartialEq for Frame<T>where
T: ReadXdr,