pub struct InnerTransactionResult {
pub fee_charged: i64,
pub result: InnerTransactionResultResult,
pub ext: InnerTransactionResultExt,
}Expand description
InnerTransactionResult is an XDR Struct defined as:
struct InnerTransactionResult
{
// Always 0. Here for binary compatibility.
int64 feeCharged;
union switch (TransactionResultCode code)
{
// txFEE_BUMP_INNER_SUCCESS is not included
case txSUCCESS:
case txFAILED:
OperationResult results<>;
case txTOO_EARLY:
case txTOO_LATE:
case txMISSING_OPERATION:
case txBAD_SEQ:
case txBAD_AUTH:
case txINSUFFICIENT_BALANCE:
case txNO_ACCOUNT:
case txINSUFFICIENT_FEE:
case txBAD_AUTH_EXTRA:
case txINTERNAL_ERROR:
case txNOT_SUPPORTED:
// txFEE_BUMP_INNER_FAILED is not included
case txBAD_SPONSORSHIP:
case txBAD_MIN_SEQ_AGE_OR_GAP:
case txMALFORMED:
case txSOROBAN_INVALID:
case txFROZEN_KEY_ACCESSED:
void;
}
result;
// reserved for future use
union switch (int v)
{
case 0:
void;
}
ext;
};Fields
fee_charged: i64result: InnerTransactionResultResultext: InnerTransactionResultExtTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for InnerTransactionResult
impl<'arbitrary> Arbitrary<'arbitrary> for InnerTransactionResult
Sourcefn arbitrary(
u: &mut Unstructured<'arbitrary>,
) -> Result<InnerTransactionResult, Error>
fn arbitrary( u: &mut Unstructured<'arbitrary>, ) -> Result<InnerTransactionResult, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<InnerTransactionResult, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<InnerTransactionResult, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for InnerTransactionResult
impl Clone for InnerTransactionResult
Sourcefn clone(&self) -> InnerTransactionResult
fn clone(&self) -> InnerTransactionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InnerTransactionResult
impl Debug for InnerTransactionResult
Sourceimpl Default for InnerTransactionResult
impl Default for InnerTransactionResult
Sourcefn default() -> InnerTransactionResult
fn default() -> InnerTransactionResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InnerTransactionResult
impl<'de> Deserialize<'de> for InnerTransactionResult
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InnerTransactionResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InnerTransactionResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InnerTransactionResult
impl Hash for InnerTransactionResult
Sourceimpl JsonSchema for InnerTransactionResult
impl JsonSchema for InnerTransactionResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for InnerTransactionResult
impl Ord for InnerTransactionResult
Sourcefn cmp(&self, other: &InnerTransactionResult) -> Ordering
fn cmp(&self, other: &InnerTransactionResult) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InnerTransactionResult
impl PartialEq for InnerTransactionResult
Sourceimpl PartialOrd for InnerTransactionResult
impl PartialOrd for InnerTransactionResult
Sourceimpl ReadXdr for InnerTransactionResult
impl ReadXdr for InnerTransactionResult
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<InnerTransactionResult, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<InnerTransactionResult, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for InnerTransactionResult
impl Serialize for InnerTransactionResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for InnerTransactionResult
impl WriteXdr for InnerTransactionResult
impl Eq for InnerTransactionResult
impl StructuralPartialEq for InnerTransactionResult