pub struct LedgerHeader {Show 15 fields
pub ledger_version: u32,
pub previous_ledger_hash: Hash,
pub scp_value: StellarValue,
pub tx_set_result_hash: Hash,
pub bucket_list_hash: Hash,
pub ledger_seq: u32,
pub total_coins: i64,
pub fee_pool: i64,
pub inflation_seq: u32,
pub id_pool: u64,
pub base_fee: u32,
pub base_reserve: u32,
pub max_tx_set_size: u32,
pub skip_list: [Hash; 4],
pub ext: LedgerHeaderExt,
}Expand description
LedgerHeader is an XDR Struct defined as:
struct LedgerHeader
{
uint32 ledgerVersion; // the protocol version of the ledger
Hash previousLedgerHash; // hash of the previous ledger header
StellarValue scpValue; // what consensus agreed to
Hash txSetResultHash; // the TransactionResultSet that led to this ledger
Hash bucketListHash; // hash of the ledger state
uint32 ledgerSeq; // sequence number of this ledger
int64 totalCoins; // total number of stroops in existence.
// 10,000,000 stroops in 1 XLM
int64 feePool; // fees burned since last inflation run
uint32 inflationSeq; // inflation sequence number
uint64 idPool; // last used global ID, used for generating objects
uint32 baseFee; // base fee per operation in stroops
uint32 baseReserve; // account base reserve in stroops
uint32 maxTxSetSize; // maximum size a transaction set can be
Hash skipList[4]; // hashes of ledgers in the past. allows you to jump back
// in time without walking the chain back ledger by ledger
// each slot contains the oldest ledger that is mod of
// either 50 5000 50000 or 500000 depending on index
// skipList[0] mod(50), skipList[1] mod(5000), etc
// reserved for future use
union switch (int v)
{
case 0:
void;
case 1:
LedgerHeaderExtensionV1 v1;
}
ext;
};Fields
ledger_version: u32previous_ledger_hash: Hashscp_value: StellarValuetx_set_result_hash: Hashbucket_list_hash: Hashledger_seq: u32total_coins: i64fee_pool: i64inflation_seq: u32id_pool: u64base_fee: u32base_reserve: u32max_tx_set_size: u32skip_list: [Hash; 4]ext: LedgerHeaderExtTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for LedgerHeader
impl<'arbitrary> Arbitrary<'arbitrary> for LedgerHeader
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<LedgerHeader, Error>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<LedgerHeader, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<LedgerHeader, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<LedgerHeader, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for LedgerHeader
impl Clone for LedgerHeader
Sourcefn clone(&self) -> LedgerHeader
fn clone(&self) -> LedgerHeader
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LedgerHeader
impl Debug for LedgerHeader
Sourceimpl Default for LedgerHeader
impl Default for LedgerHeader
Sourcefn default() -> LedgerHeader
fn default() -> LedgerHeader
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LedgerHeader
impl<'de> Deserialize<'de> for LedgerHeader
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LedgerHeader, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LedgerHeader, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LedgerHeader
impl Hash for LedgerHeader
Sourceimpl JsonSchema for LedgerHeader
impl JsonSchema for LedgerHeader
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for LedgerHeader
impl Ord for LedgerHeader
Sourcefn cmp(&self, other: &LedgerHeader) -> Ordering
fn cmp(&self, other: &LedgerHeader) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LedgerHeader
impl PartialEq for LedgerHeader
Sourceimpl PartialOrd for LedgerHeader
impl PartialOrd for LedgerHeader
Sourceimpl ReadXdr for LedgerHeader
impl ReadXdr for LedgerHeader
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<LedgerHeader, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<LedgerHeader, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for LedgerHeader
impl Serialize for LedgerHeader
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for LedgerHeader
impl WriteXdr for LedgerHeader
impl Eq for LedgerHeader
impl StructuralPartialEq for LedgerHeader