pub struct SetTrustLineFlagsOp {
pub trustor: AccountId,
pub asset: Asset,
pub clear_flags: u32,
pub set_flags: u32,
}Expand description
SetTrustLineFlagsOp is an XDR Struct defined as:
struct SetTrustLineFlagsOp
{
AccountID trustor;
Asset asset;
uint32 clearFlags; // which flags to clear
uint32 setFlags; // which flags to set
};Fields
trustor: AccountIdasset: Assetclear_flags: u32set_flags: u32Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for SetTrustLineFlagsOp
impl<'arbitrary> Arbitrary<'arbitrary> for SetTrustLineFlagsOp
Sourcefn arbitrary(
u: &mut Unstructured<'arbitrary>,
) -> Result<SetTrustLineFlagsOp, Error>
fn arbitrary( u: &mut Unstructured<'arbitrary>, ) -> Result<SetTrustLineFlagsOp, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<SetTrustLineFlagsOp, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<SetTrustLineFlagsOp, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for SetTrustLineFlagsOp
impl Clone for SetTrustLineFlagsOp
Sourcefn clone(&self) -> SetTrustLineFlagsOp
fn clone(&self) -> SetTrustLineFlagsOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetTrustLineFlagsOp
impl Debug for SetTrustLineFlagsOp
Sourceimpl Default for SetTrustLineFlagsOp
impl Default for SetTrustLineFlagsOp
Sourcefn default() -> SetTrustLineFlagsOp
fn default() -> SetTrustLineFlagsOp
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SetTrustLineFlagsOp
impl<'de> Deserialize<'de> for SetTrustLineFlagsOp
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SetTrustLineFlagsOp, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SetTrustLineFlagsOp, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SetTrustLineFlagsOp
impl Hash for SetTrustLineFlagsOp
Sourceimpl JsonSchema for SetTrustLineFlagsOp
impl JsonSchema for SetTrustLineFlagsOp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for SetTrustLineFlagsOp
impl Ord for SetTrustLineFlagsOp
Sourcefn cmp(&self, other: &SetTrustLineFlagsOp) -> Ordering
fn cmp(&self, other: &SetTrustLineFlagsOp) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SetTrustLineFlagsOp
impl PartialEq for SetTrustLineFlagsOp
Sourceimpl PartialOrd for SetTrustLineFlagsOp
impl PartialOrd for SetTrustLineFlagsOp
Sourceimpl ReadXdr for SetTrustLineFlagsOp
impl ReadXdr for SetTrustLineFlagsOp
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<SetTrustLineFlagsOp, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<SetTrustLineFlagsOp, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for SetTrustLineFlagsOp
impl Serialize for SetTrustLineFlagsOp
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for SetTrustLineFlagsOp
impl WriteXdr for SetTrustLineFlagsOp
impl Eq for SetTrustLineFlagsOp
impl StructuralPartialEq for SetTrustLineFlagsOp