pub struct SurveyResponseMessage {
pub surveyor_peer_id: NodeId,
pub surveyed_peer_id: NodeId,
pub ledger_num: u32,
pub command_type: SurveyMessageCommandType,
pub encrypted_body: EncryptedBody,
}Expand description
SurveyResponseMessage is an XDR Struct defined as:
struct SurveyResponseMessage
{
NodeID surveyorPeerID;
NodeID surveyedPeerID;
uint32 ledgerNum;
SurveyMessageCommandType commandType;
EncryptedBody encryptedBody;
};Fields
surveyor_peer_id: NodeIdsurveyed_peer_id: NodeIdledger_num: u32command_type: SurveyMessageCommandTypeencrypted_body: EncryptedBodyTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for SurveyResponseMessage
impl<'arbitrary> Arbitrary<'arbitrary> for SurveyResponseMessage
Sourcefn arbitrary(
u: &mut Unstructured<'arbitrary>,
) -> Result<SurveyResponseMessage, Error>
fn arbitrary( u: &mut Unstructured<'arbitrary>, ) -> Result<SurveyResponseMessage, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<SurveyResponseMessage, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<SurveyResponseMessage, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for SurveyResponseMessage
impl Clone for SurveyResponseMessage
Sourcefn clone(&self) -> SurveyResponseMessage
fn clone(&self) -> SurveyResponseMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SurveyResponseMessage
impl Debug for SurveyResponseMessage
Sourceimpl Default for SurveyResponseMessage
impl Default for SurveyResponseMessage
Sourcefn default() -> SurveyResponseMessage
fn default() -> SurveyResponseMessage
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SurveyResponseMessage
impl<'de> Deserialize<'de> for SurveyResponseMessage
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SurveyResponseMessage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SurveyResponseMessage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SurveyResponseMessage
impl Hash for SurveyResponseMessage
Sourceimpl JsonSchema for SurveyResponseMessage
impl JsonSchema for SurveyResponseMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for SurveyResponseMessage
impl Ord for SurveyResponseMessage
Sourcefn cmp(&self, other: &SurveyResponseMessage) -> Ordering
fn cmp(&self, other: &SurveyResponseMessage) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SurveyResponseMessage
impl PartialEq for SurveyResponseMessage
Sourceimpl PartialOrd for SurveyResponseMessage
impl PartialOrd for SurveyResponseMessage
Sourceimpl ReadXdr for SurveyResponseMessage
impl ReadXdr for SurveyResponseMessage
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<SurveyResponseMessage, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<SurveyResponseMessage, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for SurveyResponseMessage
impl Serialize for SurveyResponseMessage
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for SurveyResponseMessage
impl WriteXdr for SurveyResponseMessage
impl Eq for SurveyResponseMessage
impl StructuralPartialEq for SurveyResponseMessage