pub struct TimeSlicedNodeData {
pub added_authenticated_peers: u32,
pub dropped_authenticated_peers: u32,
pub total_inbound_peer_count: u32,
pub total_outbound_peer_count: u32,
pub p75_scp_first_to_self_latency_ms: u32,
pub p75_scp_self_to_other_latency_ms: u32,
pub lost_sync_count: u32,
pub is_validator: bool,
pub max_inbound_peer_count: u32,
pub max_outbound_peer_count: u32,
}Expand description
TimeSlicedNodeData is an XDR Struct defined as:
struct TimeSlicedNodeData
{
uint32 addedAuthenticatedPeers;
uint32 droppedAuthenticatedPeers;
uint32 totalInboundPeerCount;
uint32 totalOutboundPeerCount;
// SCP stats
uint32 p75SCPFirstToSelfLatencyMs;
uint32 p75SCPSelfToOtherLatencyMs;
// How many times the node lost sync in the time slice
uint32 lostSyncCount;
// Config data
bool isValidator;
uint32 maxInboundPeerCount;
uint32 maxOutboundPeerCount;
};Fields
added_authenticated_peers: u32dropped_authenticated_peers: u32total_inbound_peer_count: u32total_outbound_peer_count: u32p75_scp_first_to_self_latency_ms: u32p75_scp_self_to_other_latency_ms: u32lost_sync_count: u32is_validator: boolmax_inbound_peer_count: u32max_outbound_peer_count: u32Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for TimeSlicedNodeData
impl<'arbitrary> Arbitrary<'arbitrary> for TimeSlicedNodeData
Sourcefn arbitrary(
u: &mut Unstructured<'arbitrary>,
) -> Result<TimeSlicedNodeData, Error>
fn arbitrary( u: &mut Unstructured<'arbitrary>, ) -> Result<TimeSlicedNodeData, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<TimeSlicedNodeData, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<TimeSlicedNodeData, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl Clone for TimeSlicedNodeData
impl Clone for TimeSlicedNodeData
Sourcefn clone(&self) -> TimeSlicedNodeData
fn clone(&self) -> TimeSlicedNodeData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimeSlicedNodeData
impl Debug for TimeSlicedNodeData
Sourceimpl Default for TimeSlicedNodeData
impl Default for TimeSlicedNodeData
Sourcefn default() -> TimeSlicedNodeData
fn default() -> TimeSlicedNodeData
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TimeSlicedNodeData
impl<'de> Deserialize<'de> for TimeSlicedNodeData
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TimeSlicedNodeData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TimeSlicedNodeData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for TimeSlicedNodeData
impl Hash for TimeSlicedNodeData
Sourceimpl JsonSchema for TimeSlicedNodeData
impl JsonSchema for TimeSlicedNodeData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for TimeSlicedNodeData
impl Ord for TimeSlicedNodeData
Sourcefn cmp(&self, other: &TimeSlicedNodeData) -> Ordering
fn cmp(&self, other: &TimeSlicedNodeData) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TimeSlicedNodeData
impl PartialEq for TimeSlicedNodeData
Sourceimpl PartialOrd for TimeSlicedNodeData
impl PartialOrd for TimeSlicedNodeData
Sourceimpl ReadXdr for TimeSlicedNodeData
impl ReadXdr for TimeSlicedNodeData
Sourcefn read_xdr<R>(r: &mut Limited<R>) -> Result<TimeSlicedNodeData, Error>where
R: Read,
fn read_xdr<R>(r: &mut Limited<R>) -> Result<TimeSlicedNodeData, Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
fn read_xdr_base64_to_end<R>(r: &mut Limited<R>) -> Result<Self, Error>where
R: Read,
Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
fn read_xdr_into_to_end<R>(&mut self, r: &mut Limited<R>) -> Result<(), Error>where
R: Read,
Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
fn read_xdr_iter<R>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
fn read_xdr_base64_iter<R>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘwhere
R: Read,
Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for TimeSlicedNodeData
impl Serialize for TimeSlicedNodeData
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl WriteXdr for TimeSlicedNodeData
impl WriteXdr for TimeSlicedNodeData
impl Eq for TimeSlicedNodeData
impl StructuralPartialEq for TimeSlicedNodeData