Structs
- Fixed
Point - A fixed-point number: a raw integer
valueinterpreted as scaled by10^decimals(e.g. a token balance in its smallest unit alongside the token’sdecimals).
value interpreted as scaled by
10^decimals (e.g. a token balance in its smallest unit alongside the
token’s decimals).